@@ -1,22 +1,19 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
+import re
 import sys
 
+RegexType = type(re.compile(""))
+
 PY2 = int(sys.version[0]) == 2
 
 if PY2:
-    text_type = unicode
-    binary_type = str
-    string_types = (str, unicode)
     unicode = unicode
     basestring = basestring
     iterkeys = lambda d: d.iterkeys()
     itervalues = lambda d: d.itervalues()
     iteritems = lambda d: d.iteritems()
 else:
-    text_type = str
-    binary_type = bytes
-    string_types = (str,)
     unicode = str
     basestring = (str, bytes)
     iterkeys = lambda d: d.keys()
